/**
 * @license
 * Copyright Opensoft. All Rights Reserved.
 *
 * Use of this source code is governed by an Apache 2 license that can be
 * found in the LICENSE file at https://bitbucket.org/opensoftgitrepo/lightweightform/src/develop/LICENSE
 */
import program from 'commander';
import {generate} from './generator';
import {logger} from './utils';

program
  .command('generate <schemaFilePath> <outputDir> <projectName>')
  .option(
    '-g, --groupid [groupid]',
    'Maven Group Id (default=pt.lightweightform.<<projectName>>)',
  )
  .option(
    '-a, --artifactid [artifactid]',
    'Maven Artifact Id (default=<<projectName>>)',
  )
  .option(
    '--skipModules [skipModules]',
    'Skip creation of maven project (default=false)',
  )
  .option(
    '--skipValidationMessages [skipValidationMessages]',
    'Skip creation validation messages (default=false)',
  )
  .action((schemaFilePath, outputDir, projectName, options) => {
    options.groupid = options.groupid || 'pt.lightweightform';
    options.artifactid = options.artifactid || projectName;
    generate(schemaFilePath, outputDir, projectName, options);
  });

program.on('--help', function() {
  logger.info('');
  logger.info('    Options:');
  logger.info(
    '       -g, --groupid                   Maven Group Id (default=pt.lightweightform.<<projectName>>)',
  );
  logger.info(
    '       -a, --artifactid                Maven Artifact Id (default=<<projectName>>)',
  );
  logger.info(
    '       --skipModules                   Skip creation of maven project (default=false)',
  );
  logger.info(
    '       --skipValidationMessages        Skip creation validation messages (default=false)',
  );
  logger.info('  ');
  logger.info('  Examples:');
  logger.info('');
  logger.info(
    '    $ generate src/test/schema.json target/module-generated lf-app',
  );
  logger.info(
    '    $ generate src/test/schema.json target/module-generated lf-app -g pt.lf.myapp -a myapp',
  );
  logger.info(
    '    $ generate src/test/schema.json target/module-generated lf-app -g pt.lf.myapp -a myapp --skipModules',
  );
  logger.info('');
});

program.parse(process.argv);
